@@ -173,17 +173,18 @@ class Deduplicator:
             X: Pandas dataframe with column as used when fitting deduplicator instance
             score_threshold: Classification threshold to use for filtering before starting hierarchical clustering
             cluster_threshold: threshold to apply in hierarchical clustering
-            fill_missing: whether or not to apply missing value imputation on adjacency matrix
+            fill_missing: whether to apply missing value imputation on adjacency matrix
 
         Returns:
             Pandas dataframe with a new column `deduplication_id`. Rows with the same `deduplication_id` are
             deduplicated.
 
         """
-        X[ROW_ID] = np.arange(len(X))
+        df = X[self.col_names].drop_duplicates().copy()
+        df[ROW_ID] = np.arange(len(df))
         if self.verbose:
             print('blocking started')
-        pairs_table = self.myBlocker.transform(X)
+        pairs_table = self.myBlocker.transform(df)
         if self.verbose:
             print('blocking finished')
             print(f'Nr of pairs: {len(pairs_table)}')
@@ -204,9 +205,9 @@ class Deduplicator:
             scored_pairs_table.to_csv('scored_pairs_table.csv', index=None, sep="|")
         df_clusters = hierarchical_clustering(scored_pairs_table, col_names=self.col_names,
                                               cluster_threshold=cluster_threshold, fill_missing=fill_missing)
-        X = X.merge(df_clusters, on=ROW_ID, how='left').drop(columns=[ROW_ID])
+        df = df.merge(df_clusters, on=ROW_ID, how='left').drop(columns=[ROW_ID])
         if self.verbose:
             print('Clustering finished')
-        X = self._add_singletons(X)
-        X[DEDUPLICATION_ID_NAME] = X[DEDUPLICATION_ID_NAME].astype(int)
-        return X
+        df = self._add_singletons(df)
+        df[DEDUPLICATION_ID_NAME] = df[DEDUPLICATION_ID_NAME].astype(int)
+        return df
